==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/AsfBreakdown.java <==
package com.example.model;

/**
 * Model for AsfBreakdown
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "AsfBreakdown", description = "Model for AsfBreakdown")
@javax.xml.bind.annotation.XmlRootElement(name = "AsfBreakdown")
public class AsfBreakdown implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String detailCheck = null;
	private java.lang.String documentIntegrity = null;
	private java.lang.String imageComposition = null;
	private java.lang.String photoCheck = null;
	
	/**
	 */
	public AsfBreakdown detailCheck(java.lang.String detailCheck) {
		setDetailCheck(detailCheck);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("detail_check")
	@javax.validation.constraints.NotNull
	public java.lang.String getDetailCheck() {
		return this.detailCheck;
	}
	public void setDetailCheck(java.lang.String detailCheck) {
		this.detailCheck = detailCheck;
	}
	
	/**
	 */
	public AsfBreakdown documentIntegrity(java.lang.String documentIntegrity) {
		setDocumentIntegrity(documentIntegrity);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("document_integrity")
	public java.lang.String getDocumentIntegrity() {
		return this.documentIntegrity;
	}
	public void setDocumentIntegrity(java.lang.String documentIntegrity) {
		this.documentIntegrity = documentIntegrity;
	}
	
	/**
	 */
	public AsfBreakdown imageComposition(java.lang.String imageComposition) {
		setImageComposition(imageComposition);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("image_composition")
	public java.lang.String getImageComposition() {
		return this.imageComposition;
	}
	public void setImageComposition(java.lang.String imageComposition) {
		this.imageComposition = imageComposition;
	}
	
	/**
	 */
	public AsfBreakdown photoCheck(java.lang.String photoCheck) {
		setPhotoCheck(photoCheck);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("photo_check")
	public java.lang.String getPhotoCheck() {
		return this.photoCheck;
	}
	public void setPhotoCheck(java.lang.String photoCheck) {
		this.photoCheck = photoCheck;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		AsfBreakdown asfBreakdown = (AsfBreakdown) o;
		return java.util.Objects.equals(this.detailCheck, asfBreakdown.detailCheck)
				&& java.util.Objects.equals(this.documentIntegrity, asfBreakdown.documentIntegrity)
				&& java.util.Objects.equals(this.imageComposition, asfBreakdown.imageComposition)
				&& java.util.Objects.equals(this.photoCheck, asfBreakdown.photoCheck);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.detailCheck, this.documentIntegrity, this.imageComposition, this.photoCheck);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class AsfBreakdown {\n");
		
		sb.append("    detailCheck: ").append(toIndentedString(this.detailCheck)).append("\n");
		sb.append("    documentIntegrity: ").append(toIndentedString(this.documentIntegrity)).append("\n");
		sb.append("    imageComposition: ").append(toIndentedString(this.imageComposition)).append("\n");
		sb.append("    photoCheck: ").append(toIndentedString(this.photoCheck)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/AsfBreakdown.java <==
package com.example.model;

/**
 * Model for AsfBreakdown
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "AsfBreakdown", description = "Model for AsfBreakdown")
@javax.xml.bind.annotation.XmlRootElement(name = "AsfBreakdown")
public class AsfBreakdown implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String detailCheck = null;
	private java.lang.String documentIntegrity = null;
	private java.lang.String imageComposition = null;
	private java.lang.String photoCheck = null;
	
	/**
	 */
	public AsfBreakdown detailCheck(java.lang.String detailCheck) {
		setDetailCheck(detailCheck);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "detail_check")
	@com.fasterxml.jackson.annotation.JsonProperty("detail_check")
	@javax.validation.constraints.NotNull
	public java.lang.String getDetailCheck() {
		return this.detailCheck;
	}
	public void setDetailCheck(java.lang.String detailCheck) {
		this.detailCheck = detailCheck;
	}
	
	/**
	 */
	public AsfBreakdown documentIntegrity(java.lang.String documentIntegrity) {
		setDocumentIntegrity(documentIntegrity);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "document_integrity")
	@com.fasterxml.jackson.annotation.JsonProperty("document_integrity")
	public java.lang.String getDocumentIntegrity() {
		return this.documentIntegrity;
	}
	public void setDocumentIntegrity(java.lang.String documentIntegrity) {
		this.documentIntegrity = documentIntegrity;
	}
	
	/**
	 */
	public AsfBreakdown imageComposition(java.lang.String imageComposition) {
		setImageComposition(imageComposition);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "image_composition")
	@com.fasterxml.jackson.annotation.JsonProperty("image_composition")
	public java.lang.String getImageComposition() {
		return this.imageComposition;
	}
	public void setImageComposition(java.lang.String imageComposition) {
		this.imageComposition = imageComposition;
	}
	
	/**
	 */
	public AsfBreakdown photoCheck(java.lang.String photoCheck) {
		setPhotoCheck(photoCheck);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "photo_check")
	@com.fasterxml.jackson.annotation.JsonProperty("photo_check")
	public java.lang.String getPhotoCheck() {
		return this.photoCheck;
	}
	public void setPhotoCheck(java.lang.String photoCheck) {
		this.photoCheck = photoCheck;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		AsfBreakdown asfBreakdown = (AsfBreakdown) o;
		return java.util.Objects.equals(this.detailCheck, asfBreakdown.detailCheck)
				&& java.util.Objects.equals(this.documentIntegrity, asfBreakdown.documentIntegrity)
				&& java.util.Objects.equals(this.imageComposition, asfBreakdown.imageComposition)
				&& java.util.Objects.equals(this.photoCheck, asfBreakdown.photoCheck);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.detailCheck, this.documentIntegrity, this.imageComposition, this.photoCheck);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class AsfBreakdown {\n");
		
		sb.append("    detailCheck: ").append(toIndentedString(this.detailCheck)).append("\n");
		sb.append("    documentIntegrity: ").append(toIndentedString(this.documentIntegrity)).append("\n");
		sb.append("    imageComposition: ").append(toIndentedString(this.imageComposition)).append("\n");
		sb.append("    photoCheck: ").append(toIndentedString(this.photoCheck)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
